@@ -1,6 +1,7 @@
 from __future__ import annotations
+import sys
 
-from typing import TYPE_CHECKING, Iterator, Sequence, overload
+from typing import TYPE_CHECKING, Any, Iterator, Sequence, overload
 
 import rich.repr
 
@@ -13,7 +14,7 @@ class DuplicateIds(Exception):
 
 
 @rich.repr.auto(angular=True)
-class NodeList(Sequence):
+class NodeList(Sequence["Widget"]):
     """
     A container for widgets that forms one level of hierarchy.
 
@@ -46,22 +47,22 @@ class NodeList(Sequence):
     def __len__(self) -> int:
         return len(self._nodes)
 
-    def __contains__(self, widget: Widget) -> bool:
+    def __contains__(self, widget: object) -> bool:
         return widget in self._nodes
 
-    def index(self, widget: Widget) -> int:
+    def index(self, widget: Any, start: int = 0, stop: int = sys.maxsize) -> int:
         """Return the index of the given widget.
 
         Args:
-            widget (Widget): The widget to find in the node list.
+            widget: The widget to find in the node list.
 
         Returns:
-            int: The index of the widget in the node list.
+            The index of the widget in the node list.
 
         Raises:
             ValueError: If the widget is not in the node list.
         """
-        return self._nodes.index(widget)
+        return self._nodes.index(widget, start, stop)
 
     def _get_by_id(self, widget_id: str) -> Widget | None:
         """Get the widget for the given widget_id, or None if there's no matches in this list"""
@@ -71,7 +72,7 @@ class NodeList(Sequence):
         """Append a Widget.
 
         Args:
-            widget (Widget): A widget.
+            widget: A widget.
         """
         if widget not in self._nodes_set:
             self._nodes.append(widget)
@@ -86,7 +87,7 @@ class NodeList(Sequence):
         """Insert a Widget.
 
         Args:
-            widget (Widget): A widget.
+            widget: A widget.
         """
         if widget not in self._nodes_set:
             self._nodes.insert(index, widget)
@@ -111,7 +112,7 @@ class NodeList(Sequence):
         Removing a widget not in the list is a null-op.
 
         Args:
-            widget (Widget): A Widget in the list.
+            widget: A Widget in the list.
         """
         if widget in self._nodes_set:
             del self._nodes[self._nodes.index(widget)]
