@@ -187,11 +187,11 @@ def tokenize_values(values: dict[str, str]) -> dict[str, list[Token]]:
     """Tokens the values in a dict of strings.
 
     Args:
-        values (dict[str, str]): A mapping of CSS variable name on to a value, to be
+        values: A mapping of CSS variable name on to a value, to be
             added to the CSS context.
 
     Returns:
-        dict[str, list[Token]]: A mapping of name on to a list of tokens,
+        A mapping of name on to a list of tokens,
     """
     value_tokens = {
         name: list(tokenize_value(value, "__name__")) for name, value in values.items()
