@@ -140,7 +140,7 @@ Build your own or use the builtin widgets.
 - **Button** Clickable button with a number of styles.
 - **Checkbox** A checkbox to toggle between states.
 - **DataTable** A spreadsheet-like widget for navigating data. Cells may contain text or Rich renderables.
-- **TreeControl** An generic tree with expandable nodes.
+- **Tree** An generic tree with expandable nodes.
 - **DirectoryTree** A tree of file and folders.
 - *... many more planned ...*
 
@@ -410,8 +410,8 @@ class DemoApp(App):
         """Save an SVG "screenshot". This action will save an SVG file containing the current contents of the screen.
 
         Args:
-            filename (str | None, optional): Filename of screenshot, or None to auto-generate. Defaults to None.
-            path (str, optional): Path to directory. Defaults to "./".
+            filename: Filename of screenshot, or None to auto-generate. Defaults to None.
+            path: Path to directory. Defaults to "./".
         """
         self.bell()
         path = self.save_screenshot(filename, path)
