@@ -124,11 +124,11 @@ def _set_console_mode(file: IO, mode: int) -> bool:
     """Set the console mode for a given file (stdout or stdin).
 
     Args:
-        file (IO): A file like object.
-        mode (int): New mode.
+        file: A file like object.
+        mode: New mode.
 
     Returns:
-        bool: True on success, otherwise False.
+        True on success, otherwise False.
     """
     windows_filehandle = msvcrt.get_osfhandle(file.fileno())
     success = KERNEL32.SetConsoleMode(windows_filehandle, mode)
@@ -139,10 +139,10 @@ def _get_console_mode(file: IO) -> int:
     """Get the console mode for a given file (stdout or stdin)
 
     Args:
-        file (IO): A file-like object.
+        file: A file-like object.
 
     Returns:
-        int: The current console mode.
+        The current console mode.
     """
     windows_filehandle = msvcrt.get_osfhandle(file.fileno())
     mode = wintypes.DWORD()
@@ -154,7 +154,7 @@ def enable_application_mode() -> Callable[[], None]:
     """Enable application mode.
 
     Returns:
-        Callable[[], None]: A callable that will restore terminal to previous state.
+        A callable that will restore terminal to previous state.
     """
 
     terminal_in = sys.stdin
@@ -220,11 +220,9 @@ class EventMonitor(threading.Thread):
         self.target = target
         self.exit_event = exit_event
         self.process_event = process_event
-        self.app.log("event monitor constructed")
         super().__init__()
 
     def run(self) -> None:
-        self.app.log("event monitor thread started")
         exit_requested = self.exit_event.is_set
         parser = XTermParser(self.target, lambda: False)
 
@@ -265,6 +263,11 @@ class EventMonitor(threading.Thread):
                         key_event = input_record.Event.KeyEvent
                         key = key_event.uChar.UnicodeChar
                         if key_event.bKeyDown or key == "\x1b":
+                            if (
+                                key_event.dwControlKeyState
+                                and key_event.wVirtualKeyCode == 0
+                            ):
+                                continue
                             append_key(key)
                     elif event_type == WINDOW_BUFFER_SIZE_EVENT:
                         # Window size changed, store size
@@ -280,10 +283,10 @@ class EventMonitor(threading.Thread):
                     self.on_size_change(*new_size)
 
         except Exception as error:
-            self.app.log("EVENT MONITOR ERROR", error)
-        self.app.log("event monitor thread finished")
+            self.app.log.error("EVENT MONITOR ERROR", error)
 
     def on_size_change(self, width: int, height: int) -> None:
         """Called when terminal size changes."""
-        event = Resize(self.target, Size(width, height))
+        size = Size(width, height)
+        event = Resize(self.target, size, size)
         run_coroutine_threadsafe(self.target.post_message(event), loop=self.loop)
