@@ -7,7 +7,7 @@ from rich.style import Style
 
 from ._types import MessageTarget
 from .geometry import Offset, Size
-from .keys import _get_key_aliases
+from .keys import _get_key_aliases, _get_key_display
 from .message import Message
 
 MouseEventT = TypeVar("MouseEventT", bound="MouseEvent")
@@ -84,10 +84,10 @@ class Action(Event):
 class Resize(Event, bubble=False):
     """Sent when the app or widget has been resized.
     Args:
-        sender (MessageTarget): The sender of the event (the Screen).
-        size (Size): The new size of the Widget.
-        virtual_size (Size): The virtual size (scrollable size) of the Widget.
-        container_size (Size | None, optional): The size of the Widget's container widget. Defaults to None.
+        sender: The sender of the event (the Screen).
+        size: The new size of the Widget.
+        virtual_size: The virtual size (scrollable size) of the Widget.
+        container_size: The size of the Widget's container widget. Defaults to None.
 
     """
 
@@ -151,8 +151,8 @@ class MouseCapture(Event, bubble=False):
 
 
     Args:
-        sender (MessageTarget): The sender of the event, (in this case the app).
-        mouse_position (Point): The position of the mouse when captured.
+        sender: The sender of the event, (in this case the app).
+        mouse_position: The position of the mouse when captured.
 
     """
 
@@ -169,8 +169,8 @@ class MouseRelease(Event, bubble=False):
     """Mouse has been released.
 
     Args:
-        sender (MessageTarget): The sender of the event, (in this case the app).
-        mouse_position (Point): The position of the mouse when released.
+        sender: The sender of the event, (in this case the app).
+        mouse_position: The position of the mouse when released.
     """
 
     def __init__(self, sender: MessageTarget, mouse_position: Offset) -> None:
@@ -190,12 +190,12 @@ class Key(InputEvent):
     """Sent when the user hits a key on the keyboard.
 
     Args:
-        sender (MessageTarget): The sender of the event (always the App).
-        key (str): The key that was pressed.
-        character (str | None, optional): A printable character or ``None`` if it is not printable.
+        sender: The sender of the event (always the App).
+        key: The key that was pressed.
+        character: A printable character or ``None`` if it is not printable.
 
     Attributes:
-        aliases (list[str]): The aliases for the key, including the key itself.
+        aliases: The aliases for the key, including the key itself.
     """
 
     __slots__ = ["key", "character", "aliases"]
@@ -206,7 +206,7 @@ class Key(InputEvent):
         self.character = (
             (key if len(key) == 1 else None) if character is None else character
         )
-        self.aliases = _get_key_aliases(key)
+        self.aliases: list[str] = _get_key_aliases(key)
 
     def __rich_repr__(self) -> rich.repr.Result:
         yield "key", self.key
@@ -230,7 +230,7 @@ class Key(InputEvent):
         """Check if the key is printable (produces a unicode character).
 
         Returns:
-            bool: True if the key is printable.
+            True if the key is printable.
         """
         return False if self.character is None else self.character.isprintable()
 
@@ -247,18 +247,18 @@ class MouseEvent(InputEvent, bubble=True):
     """Sent in response to a mouse event.
 
     Args:
-        sender (MessageTarget): The sender of the event.
-        x (int): The relative x coordinate.
-        y (int): The relative y coordinate.
-        delta_x (int): Change in x since the last message.
-        delta_y (int): Change in y since the last message.
-        button (int): Indexed of the pressed button.
-        shift (bool): True if the shift key is pressed.
-        meta (bool): True if the meta key is pressed.
-        ctrl (bool): True if the ctrl key is pressed.
-        screen_x (int, optional): The absolute x coordinate.
-        screen_y (int, optional): The absolute y coordinate.
-        style (Style, optional): The Rich Style under the mouse cursor.
+        sender: The sender of the event.
+        x: The relative x coordinate.
+        y: The relative y coordinate.
+        delta_x: Change in x since the last message.
+        delta_y: Change in y since the last message.
+        button: Indexed of the pressed button.
+        shift: True if the shift key is pressed.
+        meta: True if the meta key is pressed.
+        ctrl: True if the ctrl key is pressed.
+        screen_x: The absolute x coordinate.
+        screen_y: The absolute y coordinate.
+        style: The Rich Style under the mouse cursor.
 
     """
 
@@ -341,7 +341,7 @@ class MouseEvent(InputEvent, bubble=True):
         """The mouse coordinate as an offset.
 
         Returns:
-            Offset: Mouse coordinate.
+            Mouse coordinate.
 
         """
         return Offset(self.x, self.y)
@@ -351,7 +351,7 @@ class MouseEvent(InputEvent, bubble=True):
         """Mouse coordinate relative to the screen.
 
         Returns:
-            Offset: Mouse coordinate.
+            Mouse coordinate.
         """
         return Offset(self.screen_x, self.screen_y)
 
@@ -360,7 +360,7 @@ class MouseEvent(InputEvent, bubble=True):
         """Mouse coordinate delta (change since last event).
 
         Returns:
-            Offset: Mouse coordinate.
+            Mouse coordinate.
 
         """
         return Offset(self.delta_x, self.delta_y)
@@ -378,10 +378,10 @@ class MouseEvent(InputEvent, bubble=True):
         """Get offset within a widget's content area, or None if offset is not in content (i.e. padding or border).
 
         Args:
-            widget (Widget): Widget receiving the event.
+            widget: Widget receiving the event.
 
         Returns:
-            Offset | None: An offset where the origin is at the top left of the content area.
+            An offset where the origin is at the top left of the content area.
         """
         if self.screen_offset not in widget.content_region:
             return None
@@ -419,22 +419,14 @@ class MouseUp(MouseEvent, bubble=True, verbose=True):
     pass
 
 
-class MouseScrollDown(InputEvent, bubble=True, verbose=True):
-    __slots__ = ["x", "y"]
-
-    def __init__(self, sender: MessageTarget, x: int, y: int) -> None:
-        super().__init__(sender)
-        self.x = x
-        self.y = y
+@rich.repr.auto
+class MouseScrollDown(MouseEvent, bubble=True):
+    pass
 
 
-class MouseScrollUp(InputEvent, bubble=True, verbose=True):
-    __slots__ = ["x", "y"]
-
-    def __init__(self, sender: MessageTarget, x: int, y: int) -> None:
-        super().__init__(sender)
-        self.x = x
-        self.y = y
+@rich.repr.auto
+class MouseScrollUp(MouseEvent, bubble=True):
+    pass
 
 
 class Click(MouseEvent, bubble=True):
@@ -489,14 +481,14 @@ class DescendantBlur(Event, bubble=True, verbose=True):
 
 
 @rich.repr.auto
-class Paste(Event, bubble=False):
+class Paste(Event, bubble=True):
     """Event containing text that was pasted into the Textual application.
     This event will only appear when running in a terminal emulator that supports
     bracketed paste mode. Textual will enable bracketed pastes when an app starts,
     and disable it when the app shuts down.
 
     Args:
-        sender (MessageTarget): The sender of the event, (in this case the app).
+        sender: The sender of the event, (in this case the app).
         text: The text that has been pasted.
     """
 
