@@ -18,8 +18,11 @@ class Message:
     """Base class for a message.
 
     Args:
-        sender (MessageTarget): The sender of the message / event.
+        sender: The sender of the message / event.
 
+    Attributes:
+        sender: The sender of the message.
+        time: The time when the message was sent.
     """
 
     __slots__ = [
@@ -38,9 +41,9 @@ class Message:
     namespace: ClassVar[str] = ""  # Namespace to disambiguate messages
 
     def __init__(self, sender: MessageTarget) -> None:
-        self.sender = sender
+        self.sender: MessageTarget = sender
 
-        self.time = _clock.get_time_no_wait()
+        self.time: float = _clock.get_time_no_wait()
         self._forwarded = False
         self._no_default_action = False
         self._stop_propagation = False
@@ -87,10 +90,10 @@ class Message:
         """Check if another message may supersede this one.
 
         Args:
-            message (Message): Another message.
+            message: Another message.
 
         Returns:
-            bool: True if this message may replace the given message
+            True if this message may replace the given message
         """
         return False
 
@@ -99,7 +102,7 @@ class Message:
         from being called.
 
         Args:
-            prevent (bool, optional): True if the default action should be suppressed,
+            prevent: True if the default action should be suppressed,
                 or False if the default actions should be performed. Defaults to True.
         """
         self._no_default_action = prevent
@@ -109,7 +112,7 @@ class Message:
         """Stop propagation of the message to parent.
 
         Args:
-            stop (bool, optional): The stop flag. Defaults to True.
+            stop: The stop flag. Defaults to True.
         """
         self._stop_propagation = stop
         return self
@@ -118,6 +121,6 @@ class Message:
         """Bubble to a widget (typically the parent).
 
         Args:
-            widget (Widget): Target of bubble.
+            widget: Target of bubble.
         """
         await widget.post_message(self)
