@@ -13,6 +13,8 @@ from typing import (
     Union,
 )
 
+import rich.repr
+
 from . import events
 from ._callback import count_parameters, invoke
 from ._types import MessageTarget
@@ -35,17 +37,21 @@ _NOT_SET = _NotSet()
 T = TypeVar("T")
 
 
+@rich.repr.auto
 class Reactive(Generic[ReactiveType]):
     """Reactive descriptor.
 
     Args:
-        default (ReactiveType | Callable[[], ReactiveType]): A default value or callable that returns a default.
-        layout (bool, optional): Perform a layout on change. Defaults to False.
-        repaint (bool, optional): Perform a repaint on change. Defaults to True.
-        init (bool, optional): Call watchers on initialize (post mount). Defaults to False.
-        always_update (bool, optional): Call watchers even when the new value equals the old value. Defaults to False.
+        default: A default value or callable that returns a default.
+        layout: Perform a layout on change. Defaults to False.
+        repaint: Perform a repaint on change. Defaults to True.
+        init: Call watchers on initialize (post mount). Defaults to False.
+        always_update: Call watchers even when the new value equals the old value. Defaults to False.
+        compute: Run compute methods when attribute is changed. Defaults to True.
     """
 
+    _reactives: TypeVar[dict[str, object]] = {}
+
     def __init__(
         self,
         default: ReactiveType | Callable[[], ReactiveType],
@@ -54,12 +60,22 @@ class Reactive(Generic[ReactiveType]):
         repaint: bool = True,
         init: bool = False,
         always_update: bool = False,
+        compute: bool = True,
     ) -> None:
         self._default = default
         self._layout = layout
         self._repaint = repaint
         self._init = init
         self._always_update = always_update
+        self._run_compute = compute
+
+    def __rich_repr__(self) -> rich.repr.Result:
+        yield self._default
+        yield "layout", self._layout
+        yield "repaint", self._repaint
+        yield "init", self._init
+        yield "always_update", self._always_update
+        yield "compute", self._run_compute
 
     @classmethod
     def init(
@@ -69,17 +85,19 @@ class Reactive(Generic[ReactiveType]):
         layout: bool = False,
         repaint: bool = True,
         always_update: bool = False,
+        compute: bool = True,
     ) -> Reactive:
         """A reactive variable that calls watchers and compute on initialize (post mount).
 
         Args:
-            default (ReactiveType | Callable[[], ReactiveType]): A default value or callable that returns a default.
-            layout (bool, optional): Perform a layout on change. Defaults to False.
-            repaint (bool, optional): Perform a repaint on change. Defaults to True.
-            always_update (bool, optional): Call watchers even when the new value equals the old value. Defaults to False.
+            default: A default value or callable that returns a default.
+            layout: Perform a layout on change. Defaults to False.
+            repaint: Perform a repaint on change. Defaults to True.
+            always_update: Call watchers even when the new value equals the old value. Defaults to False.
+            compute: Run compute methods when attribute is changed. Defaults to True.
 
         Returns:
-            Reactive: A Reactive instance which calls watchers or initialize.
+            A Reactive instance which calls watchers or initialize.
         """
         return cls(
             default,
@@ -87,6 +105,7 @@ class Reactive(Generic[ReactiveType]):
             repaint=repaint,
             init=True,
             always_update=always_update,
+            compute=compute,
         )
 
     @classmethod
@@ -97,40 +116,55 @@ class Reactive(Generic[ReactiveType]):
         """A reactive variable that doesn't update or layout.
 
         Args:
-            default (ReactiveType | Callable[[], ReactiveType]):  A default value or callable that returns a default.
+            default: A default value or callable that returns a default.
 
         Returns:
-            Reactive: A Reactive descriptor.
+            A Reactive descriptor.
         """
-        return cls(default, layout=False, repaint=False, init=True)
+        return cls(default, layout=False, repaint=False, init=False)
+
+    def _initialize_reactive(self, obj: Reactable, name: str) -> None:
+        """Initialized a reactive attribute on an object.
+
+        Args:
+            obj: An object with reactive attributes.
+            name: Name of attribute.
+        """
+        internal_name = f"_reactive_{name}"
+        if hasattr(obj, internal_name):
+            # Attribute already has a value
+            return
+        compute_method = getattr(obj, f"compute_{name}", None)
+        if compute_method is not None and self._init:
+            default = getattr(obj, f"compute_{name}")()
+        else:
+            default_or_callable = self._default
+            default = (
+                default_or_callable()
+                if callable(default_or_callable)
+                else default_or_callable
+            )
+        setattr(obj, internal_name, default)
+        if self._init:
+            self._check_watchers(obj, name, default)
 
     @classmethod
-    def _initialize_object(cls, obj: object) -> None:
+    def _initialize_object(cls, obj: Reactable) -> None:
         """Set defaults and call any watchers / computes for the first time.
 
         Args:
-            obj (Reactable): An object with Reactive descriptors
+            obj: An object with Reactive descriptors
         """
-        if not hasattr(obj, "__reactive_initialized"):
-            startswith = str.startswith
-            for key in obj.__class__.__dict__:
-                if startswith(key, "_default_"):
-                    name = key[9:]
-                    # Check defaults
-                    if not hasattr(obj, name):
-                        # Attribute has no value yet
-                        default = getattr(obj, key)
-                        default_value = default() if callable(default) else default
-                        # Set the default vale (calls `__set__`)
-                        setattr(obj, name, default_value)
-        setattr(obj, "__reactive_initialized", True)
+
+        for name, reactive in obj._reactives.items():
+            reactive._initialize_reactive(obj, name)
 
     @classmethod
     def _reset_object(cls, obj: object) -> None:
         """Reset reactive structures on object (to avoid reference cycles).
 
         Args:
-            obj (object): A reactive object.
+            obj: A reactive object.
         """
         getattr(obj, "__watchers", {}).clear()
         getattr(obj, "__computes", []).clear()
@@ -156,21 +190,24 @@ class Reactive(Generic[ReactiveType]):
 
     def __get__(self, obj: Reactable, obj_type: type[object]) -> ReactiveType:
         _rich_traceback_omit = True
-        value: _NotSet | ReactiveType = getattr(obj, self.internal_name, _NOT_SET)
-        if isinstance(value, _NotSet):
-            # No value present, we need to set the default
-            init_name = f"_default_{self.name}"
-            default = getattr(obj, init_name)
-            default_value = default() if callable(default) else default
-            # Set and return the value
-            setattr(obj, self.internal_name, default_value)
-            if self._init:
-                self._check_watchers(obj, self.name, default_value)
-            return default_value
+
+        self._initialize_reactive(obj, self.name)
+
+        value: ReactiveType
+        compute_method = getattr(self, f"compute_{self.name}", None)
+        if compute_method is not None:
+            old_value = getattr(obj, self.internal_name)
+            value = getattr(obj, f"compute_{self.name}")()
+            setattr(obj, self.internal_name, value)
+            self._check_watchers(obj, self.name, old_value)
+        else:
+            value = getattr(obj, self.internal_name)
         return value
 
     def __set__(self, obj: Reactable, value: ReactiveType) -> None:
         _rich_traceback_omit = True
+
+        self._initialize_reactive(obj, self.name)
         name = self.name
         current_value = getattr(obj, name)
         # Check for validate function
@@ -182,8 +219,13 @@ class Reactive(Generic[ReactiveType]):
         if current_value != value or self._always_update:
             # Store the internal value
             setattr(obj, self.internal_name, value)
+
             # Check all watchers
             self._check_watchers(obj, name, current_value)
+
+            if self._run_compute:
+                self._compute(obj)
+
             # Refresh according to descriptor flags
             if self._layout or self._repaint:
                 obj.refresh(repaint=self._repaint, layout=self._layout)
@@ -193,9 +235,9 @@ class Reactive(Generic[ReactiveType]):
         """Check watchers, and call watch methods / computes
 
         Args:
-            obj (Reactable): The reactable object.
-            name (str): Attribute name.
-            old_value (Any): The old (previous) value of the attribute.
+            obj: The reactable object.
+            name: Attribute name.
+            old_value: The old (previous) value of the attribute.
         """
         _rich_traceback_omit = True
         # Get the current value.
@@ -217,18 +259,21 @@ class Reactive(Generic[ReactiveType]):
             """Invoke a watch function.
 
             Args:
-                watch_function (Callable): A watch function, which may be sync or async.
-                old_value (object): The old value of the attribute.
-                value (object): The new value of the attribute.
+                watch_function: A watch function, which may be sync or async.
+                old_value: The old value of the attribute.
+                value: The new value of the attribute.
 
             Returns:
-                bool: True if the watcher was run, or False if it was posted.
+                True if the watcher was run, or False if it was posted.
             """
             _rich_traceback_omit = True
-            if count_parameters(watch_function) == 2:
+            param_count = count_parameters(watch_function)
+            if param_count == 2:
                 watch_result = watch_function(old_value, value)
-            else:
+            elif param_count == 1:
                 watch_result = watch_function(value)
+            else:
+                watch_result = watch_function()
             if isawaitable(watch_result):
                 # Result is awaitable, so we need to await it within an async context
                 obj.post_message_no_wait(
@@ -240,54 +285,43 @@ class Reactive(Generic[ReactiveType]):
             else:
                 return True
 
-        # Compute is only required if a watcher runs immediately, not if they were posted.
-        require_compute = False
         watch_function = getattr(obj, f"watch_{name}", None)
         if callable(watch_function):
-            require_compute = require_compute or invoke_watcher(
-                watch_function, old_value, value
-            )
+            invoke_watcher(watch_function, old_value, value)
 
         watchers: list[Callable] = getattr(obj, "__watchers", {}).get(name, [])
         for watcher in watchers:
-            require_compute = require_compute or invoke_watcher(
-                watcher, old_value, value
-            )
-
-        if require_compute:
-            # Run computes
-            obj.post_message_no_wait(
-                events.Callback(sender=obj, callback=partial(Reactive._compute, obj))
-            )
+            invoke_watcher(watcher, old_value, value)
 
     @classmethod
-    async def _compute(cls, obj: Reactable) -> None:
+    def _compute(cls, obj: Reactable) -> None:
         """Invoke all computes.
 
         Args:
-            obj (Reactable): Reactable object.
+            obj: Reactable object.
         """
         _rich_traceback_guard = True
-        computes = getattr(obj, "__computes", [])
-        for compute in computes:
+        for compute in obj._reactives.keys():
             try:
                 compute_method = getattr(obj, f"compute_{compute}")
             except AttributeError:
                 continue
-
-            value = await invoke(compute_method)
-            setattr(obj, compute, value)
+            current_value = getattr(obj, f"_reactive_{compute}")
+            value = compute_method()
+            setattr(obj, f"_reactive_{compute}", value)
+            if value != current_value:
+                cls._check_watchers(obj, compute, current_value)
 
 
 class reactive(Reactive[ReactiveType]):
     """Create a reactive attribute.
 
     Args:
-        default (ReactiveType | Callable[[], ReactiveType]): A default value or callable that returns a default.
-        layout (bool, optional): Perform a layout on change. Defaults to False.
-        repaint (bool, optional): Perform a repaint on change. Defaults to True.
-        init (bool, optional): Call watchers on initialize (post mount). Defaults to True.
-        always_update (bool, optional): Call watchers even when the new value equals the old value. Defaults to False.
+        default: A default value or callable that returns a default.
+        layout: Perform a layout on change. Defaults to False.
+        repaint: Perform a repaint on change. Defaults to True.
+        init: Call watchers on initialize (post mount). Defaults to True.
+        always_update: Call watchers even when the new value equals the old value. Defaults to False.
     """
 
     def __init__(
@@ -312,14 +346,21 @@ class var(Reactive[ReactiveType]):
     """Create a reactive attribute (with no auto-refresh).
 
     Args:
-        default (ReactiveType | Callable[[], ReactiveType]): A default value or callable that returns a default.
-        init (bool, optional): Call watchers on initialize (post mount). Defaults to True.
+        default: A default value or callable that returns a default.
+        init: Call watchers on initialize (post mount). Defaults to True.
     """
 
     def __init__(
-        self, default: ReactiveType | Callable[[], ReactiveType], init: bool = True
+        self,
+        default: ReactiveType | Callable[[], ReactiveType],
+        init: bool = True,
     ) -> None:
-        super().__init__(default, layout=False, repaint=False, init=init)
+        super().__init__(
+            default,
+            layout=False,
+            repaint=False,
+            init=init,
+        )
 
 
 def watch(
@@ -331,10 +372,10 @@ def watch(
     """Watch a reactive variable on an object.
 
     Args:
-        obj (Reactable): The parent object.
-        attribute_name (str): The attribute to watch.
-        callback (Callable[[Any], object]): A callable to call when the attribute changes.
-        init (bool, optional): True to call watcher initialization. Defaults to True.
+        obj: The parent object.
+        attribute_name: The attribute to watch.
+        callback: A callable to call when the attribute changes.
+        init: True to call watcher initialization. Defaults to True.
     """
 
     if not hasattr(obj, "__watchers"):
