@@ -25,10 +25,10 @@ class DirectoryTree(Tree[DirEntry]):
     """A Tree widget that presents files and directories.
 
     Args:
-        path (str): Path to directory.
-        name (str | None, optional): The name of the widget, or None for no name. Defaults to None.
-        id (str | None, optional): The ID of the widget in the DOM, or None for no ID. Defaults to None.
-        classes (str | None, optional): A space-separated list of classes, or None for no classes. Defaults to None.
+        path: Path to directory.
+        name: The name of the widget, or None for no name. Defaults to None.
+        id: The ID of the widget in the DOM, or None for no ID. Defaults to None.
+        classes: A space-separated list of classes, or None for no classes. Defaults to None.
     """
 
     COMPONENT_CLASSES: ClassVar[set[str]] = {
@@ -90,10 +90,10 @@ class DirectoryTree(Tree[DirEntry]):
         """Process a str or Text into a label. Maybe overridden in a subclass to modify how labels are rendered.
 
         Args:
-            label (TextType): Label.
+            label: Label.
 
         Returns:
-            Text: A Rich Text object.
+            A Rich Text object.
         """
         if isinstance(label, str):
             text_label = Text(label)
