@@ -45,7 +45,7 @@ class HeaderClock(HeaderClockSpace):
 
     DEFAULT_CSS = """
     HeaderClock {
-        background: $secondary-background-lighten-1;
+        background: $foreground-darken-1 5%;
         color: $text;
         text-opacity: 85%;
         content-align: center middle;
@@ -84,7 +84,7 @@ class Header(Widget):
     """A header widget with icon and clock.
 
     Args:
-        show_clock (bool, optional): True if the clock should be shown on the right of the header.
+        show_clock: True if the clock should be shown on the right of the header.
     """
 
     DEFAULT_CSS = """
@@ -97,7 +97,7 @@ class Header(Widget):
     }
     Header.-tall {
         height: 3;
-    }    
+    }
     """
 
     tall = Reactive(False)
